"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .checkoutupdate import CheckoutUpdate, CheckoutUpdateTypedDict
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CheckoutsUpdateRequestTypedDict(TypedDict):
    id: str
    r"""The checkout session ID."""
    checkout_update: CheckoutUpdateTypedDict


class CheckoutsUpdateRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The checkout session ID."""

    checkout_update: Annotated[
        CheckoutUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
